@@ -7,7 +7,7 @@ use parent qw( Class::Factory );
 use Data::Dumper qw( Dumper );
 use Workflow::Exception qw( configuration_error );
 
-$Workflow::Config::VERSION = '2.08';
+$Workflow::Config::VERSION = '2.09';
 
 # Map the valid type to the top-level XML tag or data
 # structure to look for.
@@ -117,7 +117,7 @@ Workflow::Config - Parse configuration files for the workflow components
 
 =head1 VERSION
 
-This documentation describes version 2.08 of this package
+This documentation describes version 2.09 of this package
 
 =head1 SYNOPSIS
 
@@ -306,15 +306,15 @@ workflow pieces:
       description   $
       persister     $
       initial_state $
-      observer    \@
+      observer      \@
           sub           $
           class         $
-      state       \@
+      state         \@
           name          $
           description   $
           action        \@
               name            $
-              resulting_state $
+              resulting_state $ -or- \%
               condition       \@
                   name              $
 
@@ -349,6 +349,11 @@ multiple 'action' declarations
 each 'action' declaration holds 'name' and 'resulting_state' keys and
 may hold a 'condition' key with one or more named conditions
 
+The value of the 'resulting_state' key may either be a string (the name
+of the single next state) or a hash mapping return values of the action
+to next states. The C< * > (asterisk) is the catch-all value mapping all
+unspecified values to a single next state.
+
 =item *
 
 each 'observer' names either a C<sub> or a C<class>. The C<sub> should
