@@ -12,7 +12,7 @@ use Workflow::Persister::RandomId;
 use File::Slurp qw(slurp);
 use Syntax::Keyword::Try;
 
-$Workflow::Persister::File::VERSION = '2.08';
+$Workflow::Persister::File::VERSION = '2.09';
 
 my @FIELDS = qw( path );
 __PACKAGE__->mk_accessors(@FIELDS);
@@ -191,13 +191,14 @@ Workflow::Persister::File - Persist workflow and history to the filesystem
 
 =head1 VERSION
 
-This documentation describes version 2.08 of this package
+This documentation describes version 2.09 of this package
 
 =head1 SYNOPSIS
 
- <persister name="MainPersister"
-            class="Workflow::Persister::File"
-            path="/home/workflow/storage"/>
+ persister:
+ - name: MainPersister
+   class: Workflow::Persister::File
+   path: /home/workflow/storage
 
 =head1 DESCRIPTION
 
