@@ -6,7 +6,7 @@ use v5.14.0;
 use parent qw( Workflow::Validator );
 use Workflow::Exception qw( configuration_error validation_error );
 
-$Workflow::Validator::InEnumeratedType::VERSION = '2.08';
+$Workflow::Validator::InEnumeratedType::VERSION = '2.09';
 
 sub init {
     my ( $self, $params ) = @_;
@@ -61,35 +61,39 @@ Workflow::Validator::InEnumeratedType - Ensure a value is one of a declared set
 
 =head1 VERSION
 
-This documentation describes version 2.08 of this package
+This documentation describes version 2.09 of this package
 
 =head1 SYNOPSIS
 
  # Inline the enumeration...
 
- <action name="PlayGame">
-   <validator name="InEnumeratedType">
-      <value>Rock</value>
-      <value>Scissors</value>
-      <value>Paper</value>
-      <arg value="$play"/>
-   </validator>
- </action>
+ action:
+ - name: PlayGame
+   validator:
+   - name: InEnumeratedType
+     value:
+     - Rock
+     - Scissors
+     - Paper
+     arg:
+     - '$play'
 
  # Or declare it in the validator to be more readable...
- <validator name="RSP"
-            class="Validator::InEnumeratedType">
-      <value>Rock</value>
-      <value>Scissors</value>
-      <value>Paper</value>
- </validator>
+ validator:
+ - name: RSP
+   class: Workflow::Validator::InEnumeratedType
+   value:
+   - Rock
+   - Scissors
+   - Paper
 
  # ...and use it in your action
- <action name="PlayGame">
-    <validator name="RSP">
-       <arg value="$play"/>
-    </validator>
- </action>
+ action:
+ - name: PlayGame
+   validator:
+   - name: RSP
+     arg:
+     - '$play'
 
 =head1 DESCRIPTION
 
@@ -123,25 +127,29 @@ powerful piece of reflection.
 
 Onto the code. First we declare a field type of 'worker':
 
- <field type="worker"
-        class="MyApp::Field::Worker"/>
+ field:
+ - type: worker
+   class: MyApp::Field::Worker
 
 Next a validator of this enumerated type:
 
- <validator name="IsWorker"
-            class="MyApp::Validator::WorkerEnumeration"/>
+ validator:
+ - name: IsWorker
+   class: MyApp::Validator::WorkerEnumeration
 
 We then associate this field type with a field in the action and the
 validator to ensure the user selects a worker from the right pool:
 
- <action name="AssignTicket">
-    <field name="assignee"
-           type="worker"
-           is_required="yes"/>
-   ...
-   <validator name="IsWorker">
-       <arg value="$assignee"/>
-   </validator>
+ action:
+ - name: AssignTicket
+   field:
+   - name: assignee
+     type: worker
+     is_required: yes
+   validator:
+   - name: IsWorker
+     arg:
+     - '$assignee'
 
 Note that the name of the field and the name used in the validator are
 the same. This allows external applications to query the action for
