@@ -8,7 +8,7 @@ use DateTime::Format::Strptime;
 use Workflow::Exception qw( configuration_error validation_error );
 use Scalar::Util qw( blessed );
 
-$Workflow::Validator::MatchesDateFormat::VERSION = '2.08';
+$Workflow::Validator::MatchesDateFormat::VERSION = '2.09';
 
 __PACKAGE__->mk_accessors('formatter');
 
@@ -61,16 +61,19 @@ Workflow::Validator::MatchesDateFormat - Ensure a stringified date matches a giv
 
 =head1 VERSION
 
-This documentation describes version 2.08 of this package
+This documentation describes version 2.09 of this package
 
 =head1 SYNOPSIS
 
- <action name="CreateNews">
-   <validator name="DateFormat">
-      <param name="date_format" value="%Y-%m-%d"/>
-      <arg value="$news_post_date"/>
-   </validator>
- </action>
+ action:
+ - name: CreateNews
+   validator:
+   - name: DateFormat
+     param:
+     - name: date_format
+       value: '%Y-%m-%d'
+     arg:
+     - '$news_post_date'
 
 =head1 DESCRIPTION
 
